import json
import logging
import math
import sys
from time import sleep
import os

sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "..")))
from transforms3d import euler
from interface.adapter import TcpServerAdapter, TcpClientAdapter
from util.transforms import object2tcp


class TestAdapter(TcpServerAdapter):
    vision_project_name = "Large_Non_Planar_Workpieces"
    # vision_project_name = 'Vis-2StationR7-WorkobjectRecognition-L1'
    is_force_real_run = True
    service_name = "test Adapter"

    def __init__(self, address):
        super().__init__(address)
        self.robot_service = None
        self.set_recv_size(1024)

    # Receive command _create_received_section
    def handle_command(self, cmds):
        photo_cmd, *extra_cmds = cmds.decode().split(',')
        recipe = extra_cmds[0]
        # Check command validity _check_cmd_validity_section
        if photo_cmd != 'P':
            self.msg_signal.emit(logging.ERROR, 'Illegal command: {}'.format(photo_cmd))
            self.send(('1' + '' + '').encode())
            return
        # Check whether vision is registered _check_vision_service_section

        if not self.is_vision_started():
            self.msg_signal.emit(logging.ERROR, 'Vision project not registered: {}'.format(self.vision_project_name))
            self.send(('2' + '' + '').encode())
            return
        # Change TODO parameter "extra_cmds" according to actual conditions
        sleep(0.1)  # wait for a cycle of getting in Vision
        # _check_vision_result_function_section

        try:
            result = self.select_parameter_group(self.vision_project_name, int(recipe) - 1)
            if result:
                result = result.decode()
                if result.startswith("CV-E0401"):
                    self.send(('5' + '' + '').encode())
                    return
                elif result.startswith("CV-E0403"):
                    self.send(('5' + '' + '').encode())
                    return
                raise RuntimeError(result)
        except Exception as e:
            logging.exception('Exception happened when switching model: {}'.format(e))
            self.send(('5' + '' + '').encode())
            return
        self.show_custom_message(logging.INFO, "Switched model for project successfully")

        self.msg_signal.emit(logging.WARNING, 'Started capturing image')
        try:
            self.check_vision_result(json.loads(self.find_vision_pose().decode()))

        except Exception as e:
            self.msg_signal.emit(logging.ERROR, 'Calling project timed out. Please check whether the project is correct: {}'.format(e))
            self.send(('2' + '' + '').encode())

    # Check vision results
    def check_vision_result(self, vision_result, at=None):
        noCloudInRoi = vision_result.get('noCloudInRoi', True)
        if noCloudInRoi:
            self.msg_signal.emit(logging.ERROR, 'No point clouds')
            self.send(('4' + '' + '').encode())
            return

        poses = vision_result.get('poses')
        labels = vision_result.get('labels')
        if not poses or not poses[0]:
            self.msg_signal.emit(logging.ERROR, 'No vision points')
            self.send(('3' + '' + '').encode())
            return

        self.send(self.pack_pose(poses, labels).encode())
        self.msg_signal.emit(logging.INFO, 'Sent TCP pose successfully')

    # 打包pose _pack_pose_section
    def pack_pose(self, poses, labels, at=None):

        pack_count = min(len(poses), 1)
        msg_body = ''
        for i in range(pack_count):
            pose = poses[i]
            object2tcp(pose)
            t = [p * 1000 for p in pose[:3]]
            r = [math.degrees(p) for p in euler.quat2euler(pose[3:], 'rzyx')]
            p = t + r
            self.msg_signal.emit(logging.INFO, 'Sent pose: {}'.format(p))
            msg_body += ('{:.4f},' * (len(p) - 1) + '{:.4f}').format(*p)

            if i != (pack_count - 1):
                msg_body += ','
        return '{},'.format(0) + msg_body + ''

    def close(self):
        super().close()
